Index: src/wp-includes/user.php
===================================================================
--- src/wp-includes/user.php	(revision 32827)
+++ src/wp-includes/user.php	(working copy)
@@ -2144,31 +2144,30 @@
 		// If password is changing, hash it now
 		$plaintext_pass = $userdata['user_pass'];
 		$userdata['user_pass'] = wp_hash_password( $userdata['user_pass'] );
+
 		/**
-		 * Filter to stop the sending of the password change email.
+		 * Filter to control whether the password change notification email gets sent.
 		 *
 		 * @since 4.3
 		 * @see  wp_insert_user() For $user and $userdata fields.
 		 *
 		 * @param bool Return false to not send the email.
 		 * @param array $user The original user array.
 		 * @param array $userdata The updated user array.
-		 *
 		 */
-		$send_pass_change_email = apply_filters( 'send_pass_change_email', true, $user, $userdata );
+		$send_pass_change_email = apply_filters( 'send_password_change_email', true, $user, $userdata );
 	}
 
 	if ( $user['user_email'] !== $userdata['user_email'] ) {
 		/**
-		 * Filter to stop the sending of the email change email.
+		 * Filter to control whether the email address change notification email gets sent.
 		 *
 		 * @since 4.3
 		 * @see  wp_insert_user() For $user and $userdata fields.
 		 *
-		 * @param bool Return false to not send the email.
+		 * @param bool  $send Whether to send the email address change notification email.
 		 * @param array $user The original user array.
 		 * @param array $userdata The updated user array.
-		 *
 		 */
 		$send_email_change_email = apply_filters( 'send_email_change_email', true, $user, $userdata );
 	}
@@ -2144,31 +2144,30 @@
 		 * @see  wp_insert_user() For $user and $userdata fields.
 		 *
-		 * @param bool Return false to not send the email.
+		 * @param bool  $send Whether to send the password change notification email.
 		 * @param array $user The original user array.
 		 * @param array $userdata The updated user array.
